@@ -68,7 +68,7 @@ static struct {
 static void usage(char *argv0)
 {
   fprintf(stderr, 
-"Usage: %s [-f [hex|ascii|rtcp|short|payload|dump|header] [-t minutes] [-b bytes] [multicast]/port > file\n", 
+"Usage: %s [-F [hex|ascii|rtcp|short|payload|dump|header] [-t minutes] [-b bytes] [multicast]/port > file\n", 
   argv0);
 }
 
